@@ -31,8 +31,8 @@
     
 """
 
-__author__  = "Matsumoto Taichi (taichino@gmail.com)"
-__version__ = "0.1.5"
+__author__  = "Matsumoto Taichi"
+__version__ = "0.1.6"
 __license__ = "MIT License"
 
 from croniter import croniter
